@@ -23,11 +23,11 @@
 #include <math.h>
 #include <getopt.h>
 
-#define VERSION "1.4"
+#define VERSION "1.5"
 #define max(A,B) ( (A) > (B) ? (A):(B))
 #define min(A,B) ( (A) > (B) ? (B):(A))
-#define who_play(i) ((i % 12) / 6)   //Return the player (0 ou 1) of hole i.
-#define who_wait(i) (1-(i % 12) / 6) //Return the opponent (0 ou 1) of hole i.
+#define who_plays(i) ((i % 12) / 6)   //Return the player (0 ou 1) of hole i.
+#define who_waits(i) (1-(i % 12) / 6) //Return the opponent (0 ou 1) of hole i.
 
 struct option longopts[] = {
   {"help", no_argument, NULL, 'h'},
@@ -67,7 +67,7 @@ main (int argc, char *argv[])
   void exit_game (char *);
   int best_move (int *, int *, char *);
   int ask_move (int*, int, char *);
-  int distribute (int *, int *, int, char *);
+  int distribute (int *, int *, int, char *, int);
   int hole[12] = { 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4 };
   int score[2] = { 0, 0 };
   char label[4] = "BEG";
@@ -128,8 +128,8 @@ main (int argc, char *argv[])
 	    exit (1);
 	  }
 	move--;
-	human    = who_play (move);
-	computer = who_wait (move);
+	human    = who_plays (move);
+	computer = who_waits (move);
 	break;
       case 'd':
 	flagd = 1;
@@ -219,11 +219,13 @@ main (int argc, char *argv[])
                   only possible move\n\
   -s, --single    process a single move\n\
   -i, --hint      print hints\n\
-  -x  --xawale    start in engine mode. A single line output is provided at\n\
-                  each turn. The output is board=BOARD score=SCORE move=I LABEL \n\
-                  where I is the last hole played, LABEL may be RUN if the game \n\
-		  is still running, END if the game is over or ERR if the hole of\n\
-		  the -p option is invalid.\n\n");
+  -x  --xawale    start in engine mode. A several line output is provided at\n\
+                  each turn. Each line is, \n\
+                      board=BOARD score=SCORE move=I LABEL \n\
+                  where I is the last hole played, LABEL may be COM if the turn \n\
+                  is still in computing, RUN if the turn is finished but the game  \n\
+                  is still running, END if the game is over or ERR if the played \n\
+		  hole is invalid.\n\n");
       printf ("Report bugs to <alain.le-bot@ec-lyon.fr>.\n");
 
       exit (0);
@@ -249,7 +251,7 @@ For more information about these matters, see the file named COPYING.\n");
       printf ("Rules of awale.\n\n\
 Awale game contains two lines of six holes. Each player plays a single line.\n\n\
 Every holes contain four seeds at the beginning of the game.\n\n\
-One plays alternately. One never play two turns, one cannot pass his turn.\n\n\
+One plays alternately. One never plays two turns, one cannot pass his turn.\n\n\
 When playing, take all the seeds of a hole in your line and distribute it\n\
 in successive holes turning counterclock wise, one seed per hole. Do not\n\
 put a seed in the starting hole (this case arrives when the starting hole\n\
@@ -321,7 +323,7 @@ the rule with the four following parameters.\n\
       if (!flagp || strcmp(label, "BEG"))
         {
          move = best_move (hole, score, label);
-         distribute (hole, score, move, label);
+         distribute (hole, score, move, label, 1);
          print_board (hole, score, move, label);
          if (!strcmp (label, "END") || flags) exit_game (label);
         }
@@ -330,7 +332,7 @@ the rule with the four following parameters.\n\
         {
           move = ask_move (hole, move, label);
           if (strcmp(label, "ERR"))
-            distribute (hole, score, move, label);
+            distribute (hole, score, move, label, 1);
           print_board (hole, score, move, label);
          }
        while (!strcmp(label, "ERR") && !flags);
@@ -412,7 +414,7 @@ best_move (int hole[], int score[], char *label)
   int valid (int *, int);
   int delay (int *, int *, int);
   int value (int *, int *, int, int);
-  int distribute (int *, int *, int, char *);
+  int distribute (int *, int *, int, char *, int);
   int move;
   int supv = -100, supr = -100;
   int val[12];
@@ -486,6 +488,7 @@ best_move (int hole[], int score[], char *label)
 void
 print_board (int hole[], int score[], int move, char *label)
 {
+  void outputline(int *, int *, int , char *);
   int delay (int *, int *, int);
   int value (int *, int *, int, int);
   int valid (int *, int);
@@ -494,15 +497,7 @@ print_board (int hole[], int score[], int move, char *label)
   int val[12] = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
 
   if (flagx)
-    {
-      printf ("board=");
-      for (i = 0; i < 11; i++)
-	printf ("%d-", hole[i]);
-      printf ("%d", hole[11]);
-      printf (" score=%d-%d", score[0], score[1]);
-      printf (" move=%d", move + 1);
-      printf (" %s\n", label);
-    }
+      outputline(hole, score, move, label);
   else if (strcmp(label,"ERR"))
     {
       if (flagi)
@@ -551,20 +546,35 @@ print_board (int hole[], int score[], int move, char *label)
     }
 }
 
+
+/*cccccccccccccccccccccccccccccccccccccccccccccccccccccccc
+! Generate output line for -x option.
+!ccccccccccccccccccccccccccccccccccccccccccccccccccccccc*/
+
+void
+outputline (int hole[], int score[], int move, char *label)
+{
+  printf ("board=%d-%d-%d-%d-%d-%d-%d-%d-%d-%d-%d-%d score=%d-%d move=%d %s\n",\
+    hole[0],hole[1],hole[2],hole[3],hole[4],hole[5],hole[6],hole[7],hole[8],hole[9],hole[10],hole[11],\
+    score[0],score[1],move+1,label);
+}
+
+
 /*cccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 ! Distribution of seeds.
 ! Return 1 if the game is running, 0 if the game is over.
 !ccccccccccccccccccccccccccccccccccccccccccccccccccccccc*/
 
 int
-distribute (int hole[], int score[], int i, char *label)
+distribute (int hole[], int score[], int i, char *label, int verbose)
 {
   int end_game (int *, int *, int);
+  void outputline(int *, int *, int , char *);
   int player, other;
   int n, i0, i1, j, j0, j1, na, ne;
 
-  player = who_play (i);
-  other = who_wait (i);
+  player = who_plays (i);
+  other = who_waits (i);
 
 /* distribution of seeds */
 
@@ -577,7 +587,8 @@ distribute (int hole[], int score[], int i, char *label)
       if (j != i)
         {
          hole[j]++;
-	     n--;
+	 n--;
+         if (verbose&&flagx) outputline(hole, score, i, "COM");
         }
     }
   j1=j;                 // j1 is the last hole reached
@@ -640,8 +651,8 @@ end_game (int hole[], int score[], int i)
   int player, other;
   int j, i0, i1, n;
 
-  player = who_play (i);
-  other = who_wait (i);
+  player = who_plays (i);
+  other = who_waits (i);
 
 /* the opponent has no seed */
 
@@ -704,8 +715,8 @@ valid (int hole[], int i)
 
 /* the opponent has no seed and the player doesn't provide seed */
 
-  i0 = who_play (i) * 6;
-  i1 = who_wait (i) * 6;
+  i0 = who_plays (i) * 6;
+  i1 = who_waits (i) * 6;
 
   if (hole[i1] == 0 && hole[i1 + 1] == 0 && hole[i1 + 2] == 0
       && hole[i1 + 3] == 0 && hole[i1 + 4] == 0 && hole[i1 + 5] == 0
@@ -744,8 +755,8 @@ all_is_attacked (int hole2[], int i)
   for (j = 0; j <= 11; j++)
     hole[j] = hole2[j];
     
-//  player = who_play (i);
-  other = who_wait (i);
+//  player = who_plays (i);
+  other = who_waits (i);
   
 /* Alternative algorithm for distribution
   n = i+hole[i]+hole[i]/12;
@@ -797,7 +808,7 @@ int
 value (int hole2[], int score2[], int i, int p)
 {
   int valid (int *, int);
-  int distribute (int *, int *, int, char *);
+  int distribute (int *, int *, int, char *, int);
 
   int hole[12];
   int score[2];
@@ -811,11 +822,11 @@ value (int hole2[], int score2[], int i, int p)
   for (j = 0; j <= 1; j++)
     score[j] = score2[j];
 
-  player = who_play (i);
-  other = who_wait (i);
+  player = who_plays (i);
+  other = who_waits (i);
   i1 = other * 6;
 
-  if (distribute (hole, score, i, label) && q < depth)
+  if (distribute (hole, score, i, label, 0) && q < depth)
     {
       val = -100;
       for (j = i1; j <= i1 + 5; j++)
@@ -838,7 +849,7 @@ value (int hole2[], int score2[], int i, int p)
 int
 delay (int hole2[], int score2[], int i)
 {
-  int distribute (int *, int *, int, char *);
+  int distribute (int *, int *, int, char *, int);
   int hole[12];
   int score[2];
   char label[4] = "RUN";
@@ -849,14 +860,14 @@ delay (int hole2[], int score2[], int i)
   for (j = 0; j <= 1; j++)
     score[j] = score2[j];
 
-  player = who_play (i);
+  player = who_plays (i);
   i0 = player * 6;
 
   if (i + hole[i] > i0 + 5)
     del = 0;
   else
     {
-      distribute (hole, score, i, label);
+      distribute (hole, score, i, label, 0);
       del = 0;
       for (j = i0; j <= i0 + 5; j++)
 	if (hole[j] != 0)
