@@ -16,7 +16,7 @@
 #  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
 #  USA
 #
-# Version 1.4 last modified on July 29th, 2009.
+# Version 1.5 last modified on August 22nd, 2009.
 #
 #!/bin/bash
 # start wish \
@@ -45,18 +45,18 @@ raise .copyright .
 #ccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 
 proc initGame {} {
-global trou gain label start
+global hole score label start
 global level depth depth0
 global turn iturn
 
       set label "RUN"
 
       for {set i 0} {$i<12} {incr i} {
-       set trou($i) 4
+       set hole($i) 4
       }
 
-      set gain(0) 0
-      set gain(1) 0
+      set score(0) 0
+      set score(1) 0
 
       set depth $depth0($level)
 
@@ -65,8 +65,8 @@ global turn iturn
       set iturn 0
       set turn(0) "board=4-4-4-4-4-4-4-4-4-4-4-4 score=0-0 move=0 $label"
 
-      affichage NULL
-      if {$start=="COMPUTER"} {jouer 0 1 1 4}
+      displaySeeds NULL
+      if {$start=="COMPUTER"} {play 0 1 1 4}
 
 }
 
@@ -77,7 +77,7 @@ global turn iturn
 proc importGame {} {
 global PATH LANG IFIL EFIL
 global level depth start
-global trou gain label
+global hole score label
 global turn iturn
 
 set resu [tk_getOpenFile -parent . -title $IFIL($LANG) -initialdir [file join $PATH]]
@@ -87,14 +87,15 @@ set iturn -1
 set depth [expr 7+$level]
 while {[gets $fid turn([incr iturn])]>0} {
   scan $turn($iturn) "board=%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u score=%u-%u move=%u %6s" \
-                trou(0) trou(1) trou(2) trou(3) trou(4) trou(5) \
-                trou(6) trou(7) trou(8) trou(9) trou(10) trou(11) \
-  gain(0) gain(1) mvt label
+                hole(0) hole(1) hole(2) hole(3) hole(4) hole(5) \
+                hole(6) hole(7) hole(8) hole(9) hole(10) hole(11) \
+  score(0) score(1) mvt label
 }
 incr iturn -1
 close $fid
-affichage NULL
-if {$start=="COMPUTER"&&$label=="RUN"} {jouer 0 1 1 4}
+displaySeeds NULL
+endGame
+if {$start=="COMPUTER"&&$label=="RUN"} {play 0 1 1 4}
 }
 
 #ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
@@ -115,7 +116,7 @@ close $fid
 #                     Open configure file
 #ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 
-proc openConf {} {
+proc openConfigure {} {
 global PATH LANG level nbeat noeat noall noatk start
 
 if {![catch {open [file join ~ .xawale.ini] r} fid]} {
@@ -142,7 +143,7 @@ close $fid
 #                      Save configure file
 #ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 
-proc saveConf {} {
+proc saveConfigure {} {
 global PATH LANG level nbeat noeat noall noatk start
 
 if {![catch {open [file join ~ .xawale.ini] w} fid]} {
@@ -164,30 +165,30 @@ close $fid
 #ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 
 proc undo {} {
-global trou gain label level
+global hole score label level
 global turn iturn
 set undo no
 if {$level=="H"&$iturn>=1} {incr iturn -1; set undo yes}
 if {$level!="H"&$iturn>=2} {incr iturn -2; set undo yes}
 if {$undo=="yes"} {
 scan $turn($iturn) "board=%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u score=%u-%u move=%u %6s" \
-                trou(0) trou(1) trou(2) trou(3) trou(4) trou(5) \
-                trou(6) trou(7) trou(8) trou(9) trou(10) trou(11) \
-                gain(0) gain(1) mvt label
-affichage NULL
+                hole(0) hole(1) hole(2) hole(3) hole(4) hole(5) \
+                hole(6) hole(7) hole(8) hole(9) hole(10) hole(11) \
+                score(0) score(1) mvt label
+displaySeeds NULL
 }
 }
 
 
 #ccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
-#                   Display of the board
+#              Display the board and seeds
 #ccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 
-proc affichage {mvt} {
+proc displaySeeds {mvt} {
 global LANG WIN LOSE DRAW NWIN SWIN CSCO PSCO P1CO P2CO DEPT TURN
 global level
-global trou gain label depth
-global img idtrou mvtcircle indication
+global hole score label depth
+global img idhole mvtcircle indication
 global turn iturn
 
 set a 74
@@ -195,45 +196,45 @@ set b 83
 # width of highlighted circle
 set c 4
 
-for {set i 0} {$i<12} {incr i} {.cnv delete $idtrou($i)}
+for {set i 0} {$i<12} {incr i} {.cnv delete $idhole($i)}
 .cnv delete $mvtcircle
 
-set idtrou(11)  [.cnv create image [expr 52+$b*0] [expr 135] -image $img($trou(11))]
-set idtrou(10)  [.cnv create image [expr 52+$b*1] [expr 133] -image $img($trou(10))]
-set idtrou(9)   [.cnv create image [expr 53+$b*2] [expr 131] -image $img($trou(9))]
-set idtrou(8)   [.cnv create image [expr 55+$b*3] [expr 129] -image $img($trou(8))]
-set idtrou(7)   [.cnv create image [expr 57+$b*4] [expr 130] -image $img($trou(7))]
-set idtrou(6)   [.cnv create image [expr 58+$b*5] [expr 131] -image $img($trou(6))]
-set idtrou(0)   [.cnv create image [expr 54+$b*0] [expr 219] -image $img($trou(0))]
-set idtrou(1)   [.cnv create image [expr 54+$b*1] [expr 219] -image $img($trou(1))]
-set idtrou(2)   [.cnv create image [expr 58+$b*2] [expr 215] -image $img($trou(2))]
-set idtrou(3)   [.cnv create image [expr 58+$b*3] [expr 214] -image $img($trou(3))]
-set idtrou(4)   [.cnv create image [expr 58+$b*4] [expr 214] -image $img($trou(4))]
-set idtrou(5)   [.cnv create image [expr 58+$b*5] [expr 212] -image $img($trou(5))]
+set idhole(11)  [.cnv create image [expr 52+$b*0] [expr 135] -image $img($hole(11))]
+set idhole(10)  [.cnv create image [expr 52+$b*1] [expr 133] -image $img($hole(10))]
+set idhole(9)   [.cnv create image [expr 53+$b*2] [expr 131] -image $img($hole(9))]
+set idhole(8)   [.cnv create image [expr 55+$b*3] [expr 129] -image $img($hole(8))]
+set idhole(7)   [.cnv create image [expr 57+$b*4] [expr 130] -image $img($hole(7))]
+set idhole(6)   [.cnv create image [expr 58+$b*5] [expr 131] -image $img($hole(6))]
+set idhole(0)   [.cnv create image [expr 54+$b*0] [expr 219] -image $img($hole(0))]
+set idhole(1)   [.cnv create image [expr 54+$b*1] [expr 219] -image $img($hole(1))]
+set idhole(2)   [.cnv create image [expr 58+$b*2] [expr 215] -image $img($hole(2))]
+set idhole(3)   [.cnv create image [expr 58+$b*3] [expr 214] -image $img($hole(3))]
+set idhole(4)   [.cnv create image [expr 58+$b*4] [expr 214] -image $img($hole(4))]
+set idhole(5)   [.cnv create image [expr 58+$b*5] [expr 212] -image $img($hole(5))]
 
-set idtrou(12)  [.cnv create image [expr 60+$b*2] [expr 43] -image $img($gain(1))]
-if {$gain(1)>15} {
-set idtrou(13)  [.cnv create image [expr 63+$b*3] [expr 45] -image $img([expr $gain(1)-15])]
+set idhole(12)  [.cnv create image [expr 60+$b*2] [expr 43] -image $img($score(1))]
+if {$score(1)>15} {
+set idhole(13)  [.cnv create image [expr 63+$b*3] [expr 45] -image $img([expr $score(1)-15])]
 } else {
-set idtrou(13)  [.cnv create image [expr 63+$b*3] [expr 45] -image $img(0)]
+set idhole(13)  [.cnv create image [expr 63+$b*3] [expr 45] -image $img(0)]
 }
-set idtrou(14)  [.cnv create image [expr 68+$b*2] [expr 308] -image $img($gain(0))]
-if {$gain(0)>15} {
-set idtrou(15)  [.cnv create image [expr 68+$b*3] [expr 305] -image $img([expr $gain(0)-15])]
+set idhole(14)  [.cnv create image [expr 68+$b*2] [expr 308] -image $img($score(0))]
+if {$score(0)>15} {
+set idhole(15)  [.cnv create image [expr 68+$b*3] [expr 305] -image $img([expr $score(0)-15])]
 } else {
-set idtrou(15)  [.cnv create image [expr 68+$b*3] [expr 305] -image $img(0)]
+set idhole(15)  [.cnv create image [expr 68+$b*3] [expr 305] -image $img(0)]
 }
 
 .cnv delete $indication
 if {$level=="H"} {
    set indication [.cnv create text 70 30 \
-   -text "$P1CO($LANG) $gain(1)\n$P2CO($LANG) $gain(0)\n$DEPT($LANG) $depth $TURN($LANG) $iturn"]
+   -text "$P1CO($LANG) $score(1)\n$P2CO($LANG) $score(0)\n$DEPT($LANG) $depth $TURN($LANG) $iturn"]
 } else {
    set indication [.cnv create text 70 30 \
-   -text "$CSCO($LANG) $gain(1)\n$PSCO($LANG) $gain(0)\n$DEPT($LANG) $depth $TURN($LANG) $iturn"]
+   -text "$CSCO($LANG) $score(1)\n$PSCO($LANG) $score(0)\n$DEPT($LANG) $depth $TURN($LANG) $iturn"]
 }
 
-# surlignagne du trou venant d'etre joue
+# highlights just played hole
 if {$label!="ERR"&$mvt>=1&$mvt<=12} {
 if {$mvt=="12"} {set mvtcircle [.cnv create oval [expr 15+$b*0] [expr  98] [expr 15+$b*0+$a] [expr  98+$a] -width $c]}
 if {$mvt=="11"} {set mvtcircle [.cnv create oval [expr 15+$b*1] [expr  96] [expr 15+$b*1+$a] [expr  96+$a] -width $c]}
@@ -247,12 +248,22 @@ if {$mvt=="4"}  {set mvtcircle [.cnv create oval [expr 22+$b*3] [expr 175] [expr
 if {$mvt=="3"}  {set mvtcircle [.cnv create oval [expr 22+$b*2] [expr 176] [expr 22+$b*2+$a] [expr 176+$a] -width $c]}
 if {$mvt=="2"}  {set mvtcircle [.cnv create oval [expr 17+$b*1] [expr 180] [expr 17+$b*1+$a] [expr 180+$a] -width $c]}
 if {$mvt=="1"}  {set mvtcircle [.cnv create oval [expr 17+$b*0] [expr 180] [expr 17+$b*0+$a] [expr 180+$a] -width $c]}
-after 1000 ".cnv delete $mvtcircle"
 }
 
 update
+after 400
+.cnv delete $mvtcircle
+
+}
+
+#ccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
+#             Display the message of game over
+#ccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
+
+proc endGame {} {
+global label level score
+global LANG LOSE WIN SWIN NWIN DRAW
 
-# fin de partie
 if {$label=="END"} {
   if {$level!="H"} {
      set S $LOSE($LANG)
@@ -261,32 +272,35 @@ if {$label=="END"} {
      set S $SWIN($LANG)
      set N $NWIN($LANG)
   }
-  if {$gain(0)>$gain(1)} {
-  tk_messageBox -message $S
-  } elseif {$gain(0)<$gain(1)} {
-  tk_messageBox -message $N
+  if {$score(0)>$score(1)} {
+#  tk_messageBox -message $S
+  set endmessage [.cnv create text 250 172 -text $S -font [list helvetica 36 bold]]
+  } elseif {$score(0)<$score(1)} {
+#  tk_messageBox -message $N
+  set endmessage [.cnv create text 250 172 -text $N -font [list helvetica 36 bold]]
   } else {
-  tk_messageBox -message $DRAW($LANG)
+#  tk_messageBox -message $DRAW($LANG)
+  set endmessage [.cnv create text 250 172 -text $DRAW($LANG) -font [list helvetica 36 bold]]
   }
+  after 4000 .cnv delete $endmessage
 }
 
 }
 
-
 #ccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 #                        Play
 #ccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 
-proc jouer {x y w h} {
+proc play {x y w h} {
 global BIN JOUER
 global level depth Tmin Tmax nbeat noeat noall noatk
-global trou gain label start
+global hole score label start
 global turn iturn
 
 set ligne [format %.0f [expr floor(4*$y/$h)]]
 set colon [format %.0f [expr floor(6*$x/$w)]]
-if {$ligne==1} {set trou0 [expr 12-$colon]}
-if {$ligne==2} {set trou0 [expr $colon+1]}
+if {$ligne==1} {set hole0 [expr 12-$colon]}
+if {$ligne==2} {set hole0 [expr $colon+1]}
 if {$ligne!=1&$ligne!=2} {return}
 
 .cnv configure -cursor watch
@@ -295,16 +309,9 @@ update
 # player move
 if {$level!="H"&&$ligne==2&&$label=="RUN"||$level=="H"&&$label=="RUN"} {
 
-  set turn([incr iturn]) [exec $JOUER \
-    -b $trou(0)-$trou(1)-$trou(2)-$trou(3)-$trou(4)-$trou(5)-$trou(6)-$trou(7)-$trou(8)-$trou(9)-$trou(10)-$trou(11) \
-    -o $gain(0)-$gain(1) -p $trou0 -e $nbeat [string map {" " ""} -sx$noeat$noall$noatk]]
-  scan $turn($iturn) "board=%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u score=%u-%u move=%u %6s" \
-                trou(0) trou(1) trou(2) trou(3) trou(4) trou(5) \
-                trou(6) trou(7) trou(8) trou(9) trou(10) trou(11) \
-                gain(0) gain(1) mvt label
-  if {[cyclic]==1&&$label!="ERR"} {set label "END"}
-  if {$label=="ERR"} {incr iturn -1}
-  affichage $mvt
+  displayDistribution [exec $JOUER \
+    -b $hole(0)-$hole(1)-$hole(2)-$hole(3)-$hole(4)-$hole(5)-$hole(6)-$hole(7)-$hole(8)-$hole(9)-$hole(10)-$hole(11) \
+    -o $score(0)-$score(1) -p $hole0 -e $nbeat [string map {" " ""} -sx$noeat$noall$noatk]]
 
 }
 
@@ -312,20 +319,15 @@ if {$level!="H"&&$ligne==2&&$label=="RUN"||$level=="H"&&$label=="RUN"} {
 if {$level!="H"&&$ligne==2&&$label=="RUN"||$level!="H"&&$label=="RUN"&&$start=="COMPUTER"} {
 
   set time0 [clock seconds]
-  set turn([incr iturn]) [exec $JOUER \
-    -b $trou(0)-$trou(1)-$trou(2)-$trou(3)-$trou(4)-$trou(5)-$trou(6)-$trou(7)-$trou(8)-$trou(9)-$trou(10)-$trou(11) \
-    -o $gain(0)-$gain(1) -c 2 -d $depth -e $nbeat [string map {" " ""} -sx$noeat$noall$noatk]]
-  scan $turn($iturn) "board=%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u score=%u-%u move=%u %6s" \
-                trou(0) trou(1) trou(2) trou(3) trou(4) trou(5) \
-                trou(6) trou(7) trou(8) trou(9) trou(10) trou(11) \
-                gain(0) gain(1) mvt label
+
+  displayDistribution [exec $JOUER \
+    -b $hole(0)-$hole(1)-$hole(2)-$hole(3)-$hole(4)-$hole(5)-$hole(6)-$hole(7)-$hole(8)-$hole(9)-$hole(10)-$hole(11) \
+    -o $score(0)-$score(1) -c 2 -d $depth -e $nbeat [string map {" " ""} -sx$noeat$noall$noatk]]
+
   set time [expr [clock seconds]-$time0]
   if {$time==0}            {after 1000}
   if {$time>$Tmax($level)} {incr depth -1}
   if {$time<$Tmin($level)} {incr depth  1}
-  if {[cyclic]==1&&$label!="ERR"} {set label "END"}
-  if {$label=="ERR"} {incr iturn -1}
-  affichage $mvt
 
 }
 
@@ -333,18 +335,44 @@ if {$level!="H"&&$ligne==2&&$label=="RUN"||$level!="H"&&$label=="RUN"&&$start=="
 if {$label=="ERR"} {set label "RUN"}
 }
 
+#ccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
+#          Display the distribution of seeds
+#ccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
+
+proc displayDistribution {awaleoutput} {
+  global hole score label
+  global turn iturn
+
+  set lines [split $awaleoutput "\n"]
+  foreach line $lines {
+    scan $line "board=%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u-%u score=%u-%u move=%u %6s" \
+                hole(0) hole(1) hole(2) hole(3) hole(4) hole(5) \
+                hole(6) hole(7) hole(8) hole(9) hole(10) hole(11) \
+                score(0) score(1) mvt label
+#tk_messageBox -message "$line mvt=$mvt"
+    displaySeeds $mvt
+  }
+  if {$label!="ERR"} {set turn([incr iturn]) $line}
+  if {[cyclic]==1&&$label!="ERR"} {set label "END"}
+  endGame
+
+}
+
 #ccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 #                        Cyclic
 #ccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 
 proc cyclic {} {
-global trou gain label
+global hole score label
 global turn iturn
 
 set n [string first " score" turn($iturn)]
 
 for {set i 1} {$i<$iturn} {incr i} {
-  if {[string compare -length $n $turn($i) $turn($iturn)]==0} {return 1}
+  if {[string compare -length $n $turn($i) $turn($iturn)]==0} {
+#     tk_messageBox -message "same position found in turn $i"
+     return 1
+  }
 }
 
 return 0
@@ -355,27 +383,27 @@ return 0
 #                   Display the content of a hole
 #ccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
 
-proc contenu {x y w h} {
+proc displayContent {x y w h} {
 global level depth
-global trou gain label LANG SEED
+global hole score label LANG SEED
 
 set ligne [format %.0f [expr floor(4*$y/$h)]]
 set colon [format %.0f [expr floor(6*$x/$w)]]
 
 if {$ligne==0&$label=="RUN"} {
-   after 1000 ".cnv delete [.cnv create text 38 70 -text "$gain(1) $SEED($LANG)"]"
+   after 1000 ".cnv delete [.cnv create text 38 70 -text "$score(1) $SEED($LANG)"]"
 }
 
 if {$ligne==1&$label=="RUN"} {
-   after 1000 ".cnv delete [.cnv create text 38 70 -text "$trou([expr 11-$colon]) $SEED($LANG)"]"
+   after 1000 ".cnv delete [.cnv create text 38 70 -text "$hole([expr 11-$colon]) $SEED($LANG)"]"
 }
 
 if {$ligne==2&$label=="RUN"} {
-   after 1000 ".cnv delete [.cnv create text 38 70 -text "$trou($colon) $SEED($LANG)"]"
+   after 1000 ".cnv delete [.cnv create text 38 70 -text "$hole($colon) $SEED($LANG)"]"
 }
 
 if {$ligne==3&$label=="RUN"} {
-   after 2000 ".cnv delete [.cnv create text 38 70 -text "$gain(0) $SEED($LANG)"]"
+   after 2000 ".cnv delete [.cnv create text 38 70 -text "$score(0) $SEED($LANG)"]"
 }
 
 
@@ -655,7 +683,7 @@ global label
 .menu.help entryconfigure  0 -label $RULE($LANG)
 .menu.help entryconfigure  1 -label $ABOU($LANG)
 
-if {$label=="BEG"|$label=="RUN"} {affichage NULL}
+if {$label=="BEG"|$label=="RUN"} {displaySeeds NULL}
 }
 
 
@@ -665,13 +693,13 @@ if {$label=="BEG"|$label=="RUN"} {affichage NULL}
 
 switch $tcl_platform(platform) {
 "unix"      {
-    set JOUER awale
+    set JOUER [file join [file dirname [info script]] .. .. bin awale] 
             }
 "macintosh" {
-    set JOUER awale
+    set JOUER [file join [file dirname [info script]] .. .. bin awale]
             }
 "windows"   {
-    set JOUER awale.exe
+    set JOUER [file join [file dirname [info script]] .. .. bin awale.exe]
             }
 }
 
@@ -688,7 +716,7 @@ set noeat " "
 set noall " "
 set noatk " "
 set label END
-for {set i 0} {$i<12} {incr i} {set idtrou($i) 0}
+for {set i 0} {$i<12} {incr i} {set idhole($i) 0}
 set mvtcircle 0
 set iturn 0
 set indication 0
@@ -764,11 +792,11 @@ array set EFIL [list uk "ERROR when opening file" \
                      fr "ERREUR lors de l'ouverture du fichier" \
                      sp "ERROR cuando se abre el fichero"]
 
-openConf
+openConfigure
 
-wm title . "Awale"
+wm title . "Free Awale"
 
-# creation du menu
+# creation of menu
 
 menu .menu -tearoff 0
 
@@ -779,7 +807,7 @@ $m add command -label $NEW($LANG)  -accelerator Crtl+N -command {initGame}
 $m add command -label $OPEN($LANG) -accelerator Crtl+O -command {importGame}
 $m add command -label $SAVE($LANG) -accelerator Crtl+S -command {saveGame}
 $m add command -label $UNDO($LANG) -accelerator Crtl+Z -command {undo}
-$m add command -label $QUIT($LANG) -accelerator Crtl+Q -command {saveConf; destroy .}
+$m add command -label $QUIT($LANG) -accelerator Crtl+Q -command {saveConfigure; destroy .}
 bind . <Control-n> {initGame}
 bind . <Control-o> {importGame}
 bind . <Control-s> {saveGame}
@@ -820,7 +848,7 @@ $m add command -label $ABOU($LANG) -command {copyrightDialog FALSE}
 
 # creation of the main image
 
-set fond [image create photo -file [file join $BIN Awale.gif]]
+set fond [image create photo -file [file join $BIN board.gif]]
 set largeur [image width $fond]
 set hauteur [image height $fond]
 for {set i  0} {$i<10} {incr i} {set img($i) [image create photo -file [file join $BIN Trou0$i.gif]]}
@@ -828,13 +856,16 @@ for {set i 10} {$i<16} {incr i} {set img($i) [image create photo -file [file joi
 for {set i 16} {$i<49} {incr i} {set img($i) [image create photo -file [file join $BIN Trou15.gif]]}
 
 canvas .cnv -width $largeur -height $hauteur -cursor top_left_arrow
-bind .cnv <ButtonPress-1> "jouer %x %y $largeur $hauteur"
-bind .cnv <ButtonPress-3> "contenu %x %y $largeur $hauteur"
+bind .cnv <ButtonPress-1> "play %x %y $largeur $hauteur"
+bind .cnv <ButtonPress-2> "displayContent %x %y $largeur $hauteur"
+bind .cnv <ButtonPress-3> "displayContent %x %y $largeur $hauteur"
 pack .cnv -side top -anchor nw
 
+wm geometry . +400+100
+
 .cnv create image [expr $largeur/2] [expr $hauteur/2] -image $fond
 
-# ecran d'acceuil
+# welcome window
 
 copyrightDialog TRUE
-after 2000 {destroy .copyright}
+after 2000 {destroy .copyright; focus .}
